@@ -13,7 +13,7 @@ class ConfigTools:
 
     def load_configs(self):
         """load configs from file."""
-        with open(f"{os.path.dirname(__file__)}/../config/config.json", "r") as file:
+        with open(f"{os.path.join(os.path.dirname(__file__),'..','config','config.json')}", "r") as file:
             data = json.loads(file.read())
         return data
 
@@ -26,7 +26,7 @@ class ConfigTools:
     def set(self, key, value):
         data = self.load_configs()
         data[key] = value
-        with open(f"{os.path.dirname(__file__)}/../config/config.json", "w") as file:
+        with open(f"{os.path.join(os.path.dirname(__file__),'..','config','config.json')}", "w") as file:
             json.dump(data, file, indent=4)
 
     def get(self, key):
